@@ -1,4 +1,5 @@
 import argparse
+import os
 import sys
 import traceback
 
@@ -19,14 +20,12 @@ def main():
     parser.add_argument(
         "--username",
         type=str,
-        default=explainaboard_client.username,
         help="Username used to sign in to ExplainaBoard. Defaults to the EB_USERNAME "
         "environment variable.",
     )
     parser.add_argument(
         "--api-key",
         type=str,
-        default=explainaboard_client.api_key,
         help="API key for ExplainaBoard. Defaults to the EB_API_KEY environment "
         "variable.",
     )
@@ -46,22 +45,24 @@ def main():
     )
     args = parser.parse_args()
 
-    explainaboard_client.username = args.username
-    explainaboard_client.api_key = args.api_key
+    explainaboard_client.username = (
+        args.username if args.username is not None else os.environ.get("EB_USERNAME")
+    )
+    explainaboard_client.api_key = (
+        args.api_key if args.api_key is not None else os.environ.get("EB_API_KEY")
+    )
     client = ExplainaboardClient()
 
     system_strs = []
     for system_id in tqdm(args.system_ids, desc="retrieving system info"):
         try:
             system_dict = client.get_system(system_id)
-
-            dataset = system_dict["system_info"].get("dataset_name", "custom dataset")
-            subdataset = system_dict["system_info"].get(
-                "sub_dataset_name", "custom dataset"
-            )
+            dataset_dict = system_dict.get("dataset", {})
+            dataset = dataset_dict.get("dataset_name", "custom dataset")
+            subdataset = dataset_dict.get("sub_dataset", "")
             system_strs.append(
                 f"id={system_id}, "
-                f'name={system_dict["system_info"]["system_name"]}, '
+                f'name={system_dict["system_name"]}, '
                 f"dataset={dataset}, "
                 f"subdataset={subdataset}, "
                 f'created_at={str(system_dict["created_at"])}'
