@@ -1,5 +1,6 @@
 import argparse
 import json
+import os
 import traceback
 
 import explainaboard_client
@@ -19,14 +20,12 @@ def main():
     parser.add_argument(
         "--username",
         type=str,
-        default=explainaboard_client.username,
         help="Username used to sign in to ExplainaBoard. Defaults to the EB_USERNAME "
         "environment variable.",
     )
     parser.add_argument(
         "--api-key",
         type=str,
-        default=explainaboard_client.api_key,
         help="API key for ExplainaBoard. Defaults to the EB_API_KEY environment "
         "variable.",
     )
@@ -112,8 +111,12 @@ def main():
     )
     args = parser.parse_args()
 
-    explainaboard_client.username = args.username
-    explainaboard_client.api_key = args.api_key
+    explainaboard_client.username = (
+        args.username if args.username is not None else os.environ.get("EB_USERNAME")
+    )
+    explainaboard_client.api_key = (
+        args.api_key if args.api_key is not None else os.environ.get("EB_API_KEY")
+    )
     client = ExplainaboardClient()
 
     try:
@@ -149,13 +152,9 @@ def main():
     # Print accuracy numbers
     if evaluation_data is not None:
         try:
-            overall_results = evaluation_data["system_info"]["results"]["overall"][0]
-            for result in overall_results:
-                print(
-                    f'{result["metric_name"]}: {result["value"]:.4f} '
-                    f'[{result["confidence_score_low"]:.4f}, '
-                    f'{result["confidence_score_high"]:.4f}]'
-                )
+            results = evaluation_data["results"]["example"].items()
+            for metric_name, value in results:
+                print(f"{metric_name}: {value:.4f}")
         except Exception:
             pass
 
